@@ -148,11 +148,11 @@ accrate.depth.ghost <- function(set=get('info'), d=set$d, d.lim=c(), acc.lim=c()
   if(length(d.lim) == 0)
     d.lim <- range(d)  
   if(length(d.lab) == 0)
-    d.lab <- paste("depth (", set$unit, ")", sep="")
+    d.lab <- paste("depth (", set$depth.unit, ")", sep="")
   if(length(acc.lab) == 0)
     if(cmyr)
-      acc.lab <- paste("accumulation rate (", set$unit, "/yr)", sep="") else
-        acc.lab <- paste("accumulation rate (yr/", set$unit, ")", sep="") 
+      acc.lab <- paste0("accumulation rate (", set$depth.unit, "/", set$age.unit, ")") else
+        acc.lab <- paste0("accumulation rate (", set$age.unit, "/", set$depth.unit, ")") 
   
   if(rev.d) 
     d.lim <- rev(d.lim)
@@ -198,9 +198,12 @@ accrate.depth.ghost <- function(set=get('info'), d=set$d, d.lim=c(), acc.lim=c()
 #' This is due to only some MCMC iterations reaching those old ages, and these iterations will have modelled very slow accumulation rates. 
 #' Currently does not deal well with hiatuses, so do not interpret accumulation rates close to depths with inferred hiatuses.
 #' @param set Detailed information of the current run, stored within this session's memory as variable info.
-#' @param yr.lim Minimum and maximum calendar age ranges, calculated automatically by default (\code{yr.lim=c()}).
-#' @param yr.lab The labels for the calendar axis (default \code{yr.lab="cal BP"} or \code{"BC/AD"} if \code{BCAD=TRUE}).
-#' @param yr.res Resolution or amount of greyscale pixels to cover the age scale of the age-model plot. Default \code{yr.res=200}.
+#' @param age.lim Minimum and maximum calendar age ranges, calculated automatically by default (\code{age.lim=c()}).
+#' @param yr.lim Deprecated - use age.lim instead
+#' @param age.lab The labels for the calendar axis (default \code{age.lab="cal BP"} or \code{"BC/AD"} if \code{BCAD=TRUE}).
+#' @param yr.lab Deprecated - use age.lab instead
+#' @param age.res Resolution or amount of greyscale pixels to cover the age scale of the age-model plot. Default \code{age.res=200}.
+#' @param yr.res Deprecated - use age.res instead
 #' @param grey.res Resolution of greyscales. Default \code{grey.res=50}, which does not aim to poke fun at a famous novel.
 #' @param prob Probability ranges. Defaults to \code{prob=0.95}.
 #' @param plot.range If \code{plot.range=TRUE}, the confidence ranges (two-tailed; half of the probability at each side) are plotted. 
@@ -216,7 +219,8 @@ accrate.depth.ghost <- function(set=get('info'), d=set$d, d.lim=c(), acc.lim=c()
 #' @param BCAD The calendar scale of graphs and age output-files is in \code{cal BP} by default, but can be changed to BC/AD using \code{BCAD=TRUE}. 
 #' @param cmyr Accumulation rates can be calculated in cm/year or year/cm. By default \code{cmyr=FALSE} and accumulation rates are calculated in year per cm. Axis limits are difficult to calculate when \code{cmyr=TRUE}, so a manual adaptation of \code{acc.lim} might be a good idea.
 #' @param rotate.axes The default is to plot the calendar age horizontally and accumulation rates vertically. Change to \code{rotate.axes=TRUE} value to rotate axes.
-#' @param rev.yr The direction of the age axis, which can be reversed using \code{rev.yr=TRUE}.
+#' @param rev.age The direction of the age axis, which can be reversed using \code{rev.age=TRUE}.
+#' @param rev.yr Deprecated - use rev.age instead
 #' @param rev.acc The direction of the accumulation rate axis, which can be reversed (\code{rev.acc=TRUE}.
 #' @param xaxs Extension of the x-axis. White space can be added to the vertical axis using \code{xaxs="r"}.	
 #' @param yaxs Extension of the y-axis. White space can be added to the vertical axis using \code{yaxs="r"}.
@@ -234,29 +238,29 @@ accrate.depth.ghost <- function(set=get('info'), d=set$d, d.lim=c(), acc.lim=c()
 #' gamma process. Bayesian Anal. 6 (2011), no. 3, 457--474. 
 #' \url{https://projecteuclid.org/download/pdf_1/euclid.ba/1339616472}
 #' @export
-accrate.age.ghost <- function(set=get('info'), yr.lim=c(), yr.lab=c(), yr.res=200, grey.res=50, prob=.95, plot.range=TRUE, range.col=grey(0.5), range.lty=2, plot.mean=TRUE, mean.col="red", mean.lty=2, acc.lim=c(), acc.lab=c(), upper=0.99, dark=50, BCAD=set$BCAD, cmyr=FALSE, rotate.axes=FALSE, rev.yr=FALSE, rev.acc=FALSE, xaxs="i", yaxs="i", bty="o") {
+accrate.age.ghost <- function(set=get('info'), age.lim=c(), yr.lim=age.lim, age.lab=c(), yr.lab=age.lab, age.res=200, yr.res=age.res, grey.res=50, prob=.95, plot.range=TRUE, range.col=grey(0.5), range.lty=2, plot.mean=TRUE, mean.col="red", mean.lty=2, acc.lim=c(), acc.lab=c(), upper=0.99, dark=50, BCAD=set$BCAD, cmyr=FALSE, rotate.axes=FALSE, rev.age=FALSE, rev.yr=rev.age, rev.acc=FALSE, xaxs="i", yaxs="i", bty="o") {
   if(length(yr.lim) == 0) {
     min.age <- min(set$ranges[,2])
     max.age <- max(set$ranges[,3])
   } else {
-      min.age <- min(yr.lim)
-      max.age <- max(yr.lim)
+      min.age <- min(age.lim)
+      max.age <- max(age.lim)
     }
    
-  yr.seq <- seq(min.age, max.age, length=yr.res)
-  pb <- txtProgressBar(min=0, max=max(1,length(yr.seq)-1), style = 3) 
+  age.seq <- seq(min.age, max.age, length=age.res)
+  pb <- txtProgressBar(min=0, max=max(1,length(age.seq)-1), style = 3) 
   max.y <- 0; all.x <- c()
   hist.list <- list(x=c(), y=c(), min.rng=c(), max.rng=c(), mn.rng=c())
-  for(i in 1:length(yr.seq)) {
+  for(i in 1:length(age.seq)) {
     setTxtProgressBar(pb, i)
-    acc <- accrate.age(yr.seq[i], set, cmyr=cmyr)
+    acc <- accrate.age(age.seq[i], set, cmyr=cmyr)
     if(cmyr) acc <- rev(acc)
       accs <- acc
     if(length(acc) > 2)
     if(length(acc.lim) == 0)
       acc <- density(acc, from=0) else
         acc <- density(acc, from=0, to=max(acc.lim))
-    hist.list$yr[[i]] <- yr.seq[i]
+    hist.list$yr[[i]] <- age.seq[i]
     hist.list$x[[i]] <- acc$x
     hist.list$y[[i]] <- acc$y/sum(acc$y)
     rng <- quantile(accs, c((1-prob)/2, 1-((1-prob)/2)))
@@ -269,28 +273,28 @@ accrate.age.ghost <- function(set=get('info'), yr.lim=c(), yr.lab=c(), yr.res=20
   cat("\n")
   
   if(BCAD) 
-    yr.seq <- 1950 - yr.seq
-  if(length(yr.lim) == 0)
-    yr.lim <- range(yr.seq)
+    age.seq <- 1950 - age.seq
+  if(length(age.lim) == 0)
+    age.lim <- range(age.seq)
   if(length(acc.lim) == 0)
     acc.lim <- c(0, 1.1*quantile(all.x, upper))
   if(BCAD)
-    yr.lim <- rev(yr.lim)
-  if(rev.yr)
-    yr.lim <- rev(yr.lim)
+    age.lim <- rev(age.lim)
+  if(rev.age)
+    age.lim <- rev(age.lim)
   if(rev.acc)
     acc.lim <- rev(acc.lim)
-  if(length(yr.lab) == 0)
+  if(length(age.lab) == 0)
     if(BCAD)
-      yr.lab <- "BC/AD" else
-        yr.lab <- "cal BP"    
+      age.lab <- "BC/AD" else
+        age.lab <- "cal BP"    
   if(length(acc.lab) == 0)
     if(cmyr)
-      acc.lab <- paste("accumulation rate (", set$unit, "/yr)", sep="") else
-        acc.lab <- paste("accumulation rate (yr/", set$unit, ")", sep="") 
+      acc.lab <- paste0("accumulation rate (", set$depth.unit, "/", set$age.unit, ")") else
+        acc.lab <- paste0("accumulation rate (", set$age.unit, "/", set$depth.unit, ")") 
   if(rotate.axes) {
-    plot(0, type="n", xlim=acc.lim, xlab=acc.lab, ylim=yr.lim, ylab=yr.lab, xaxs=xaxs, yaxs=yaxs)
-    for(i in 2:length(yr.seq)) {
+    plot(0, type="n", xlim=acc.lim, xlab=acc.lab, ylim=age.lim, ylab=age.lab, xaxs=xaxs, yaxs=yaxs)
+    for(i in 2:length(age.seq)) {
       if(BCAD) 
         image(sort(hist.list$x[[i]]), 1950-hist.list$yr[c(i,i-1)], t(t(matrix(hist.list$y[[i]]))),
           col=grey(seq(1, 1-min(1,max(hist.list$y[[i]])*dark/max.y), length=grey.res)), add=TRUE) else
@@ -298,8 +302,8 @@ accrate.age.ghost <- function(set=get('info'), yr.lim=c(), yr.lab=c(), yr.res=20
             col=grey(seq(1, 1-min(1,max(hist.list$y[[i]])*dark/max.y), length=grey.res)), add=TRUE)
     }
   } else {
-        plot(0, type="n", xlim=yr.lim, xlab=yr.lab, ylim=acc.lim, ylab=acc.lab, xaxs=xaxs, yaxs=yaxs)
-        for(i in 2:length(yr.seq)) {
+        plot(0, type="n", xlim=age.lim, xlab=age.lab, ylim=acc.lim, ylab=acc.lab, xaxs=xaxs, yaxs=yaxs)
+        for(i in 2:length(age.seq)) {
           if(BCAD)
             image(sort(1950-hist.list$yr[c(i,i-1)]), hist.list$x[[i]], t(matrix(hist.list$y[[i]])),
               col=grey(seq(1, 1-min(1,max(hist.list$y[[i]])*dark/max.y), length=grey.res)), add=TRUE) else
@@ -309,16 +313,16 @@ accrate.age.ghost <- function(set=get('info'), yr.lim=c(), yr.lab=c(), yr.res=20
       }
    if(plot.range)
      if(rotate.axes) {
-       lines(hist.list$min.rng, yr.seq, pch=".", col=range.col, lty=range.lty)
-       lines(hist.list$max.rng, yr.seq, pch=".", col=range.col, lty=range.lty)
+       lines(hist.list$min.rng, age.seq, pch=".", col=range.col, lty=range.lty)
+       lines(hist.list$max.rng, age.seq, pch=".", col=range.col, lty=range.lty)
      } else {
-       lines(yr.seq, hist.list$min.rng, pch=".", col=range.col, lty=range.lty)
-       lines(yr.seq, hist.list$max.rng, pch=".", col=range.col, lty=range.lty)
+       lines(age.seq, hist.list$min.rng, pch=".", col=range.col, lty=range.lty)
+       lines(age.seq, hist.list$max.rng, pch=".", col=range.col, lty=range.lty)
        }
      if(plot.mean)
        if(rotate.axes)
-         lines(hist.list$mn.rng, yr.seq, pch=".", col=mean.col, lty=mean.lty) else
-           lines(yr.seq, hist.list$mn.rng, pch=".", col=mean.col, lty=mean.lty)
+         lines(hist.list$mn.rng, age.seq, pch=".", col=mean.col, lty=mean.lty) else
+           lines(age.seq, hist.list$mn.rng, pch=".", col=mean.col, lty=mean.lty)
       
   if(length(bty) > 0)
     box(bty=bty)
@@ -337,13 +341,15 @@ accrate.age.ghost <- function(set=get('info'), yr.lim=c(), yr.lab=c(), yr.res=20
 #'  within the R session (consisting of depths and their proxy concentrations in two columns). Then provide the name of this variable, e.g.: \code{flux.age.ghost(flux=flux1)}. 
 #' See Bacon_runs/MSB2K/MSB2K_flux.csv for an example.
 #' @param proxy Which proxy to use (counting from the column number in the .csv file after the depths column). 
-#' @param yr.lim Minimum and maximum calendar age ranges, calculated automatically by default (\code{yr.lim=c()}).
-#' @param yr.res Resolution or amount of greyscale pixels to cover the age scale of the plot. Default \code{yr.res=200}.
+#' @param age.lim Minimum and maximum calendar age ranges, calculated automatically by default (\code{age.lim=c()}).
+#' @param yr.lim Deprecated - use age.lim instead
+#' @param age.res Resolution or amount of greyscale pixels to cover the age scale of the plot. Default \code{age.res=200}.
+#' @param yr.res Deprecated - use age.res instead
 #' @param set Detailed information of the current run, stored within this session's memory as variable info.
 #' @param flux Define a flux variable within the R session (consisting of depths and their proxy concentrations in two columns) and provide the name of this variable, e.g.: 
 #' \code{flux.age.ghost(flux=flux1)}. If left empty (\code{flux=c()}), a flux file is expected (see \code{proxy}).
 #' @param plot.range Plot curves that indicate a probability range, at resolution of yr.res.
-#' @param prob	Probability range, defaults to \code{prob=0.8} (10 \% at each side). 
+#' @param prob Probability range, defaults to \code{prob=0.8} (10 \% at each side). 
 #' @param range.col Red seems nice. 
 #' @param range.lty Line type of the confidence ranges.
 #' @param flux.lim Limits of the flux axes.
@@ -354,10 +360,12 @@ accrate.age.ghost <- function(set=get('info'), yr.lim=c(), yr.lab=c(), yr.res=20
 #' @param upper Maximum flux rates to plot. Defaults to the upper 99\%; \code{upper=0.99}.
 #' @param dark The darkest grey value is \code{dark=1} by default; lower values will result in lighter grey but \code{values >1} are not allowed.
 #' @param BCAD The calendar scale of graphs and age output-files is in \code{cal BP} by default, but can be changed to BC/AD using \code{BCAD=TRUE}. 
-#' @param yr.lab The labels for the calendar axis (default \code{yr.lab="cal BP"} or \code{"BC/AD"} if \code{BCAD=TRUE}).
+#' @param age.lab The labels for the calendar axis (default \code{age.lab="cal BP"} or \code{"BC/AD"} if \code{BCAD=TRUE}).
+#' @param yr.lab Deprecated - use age.lab instead
 #' @param rotate.axes The default of plotting calendar year on the horizontal axis and fluxes on the vertical one can be changed with \code{rotate.axes=TRUE}.
 #' @param rev.flux The flux axis can be reversed with \code{rev.flux=TRUE}.
-#' @param rev.yr The direction of the age axis can be reversed using \code{rev.yr=TRUE}.
+#' @param rev.age The direction of the age axis can be reversed using \code{rev.age=TRUE}.
+#' @param rev.yr Deprecated - use rev.age instead
 #' @author Maarten Blaauw, J. Andres Christen
 #' @return A plot of flux rates.
 #' @examples
@@ -372,23 +380,23 @@ accrate.age.ghost <- function(set=get('info'), yr.lim=c(), yr.lab=c(), yr.res=20
 #' gamma process. Bayesian Anal. 6 (2011), no. 3, 457--474. 
 #' \url{https://projecteuclid.org/download/pdf_1/euclid.ba/1339616472}
 #' @export
-flux.age.ghost <- function(proxy=1, yr.lim=c(), yr.res=200, set=get('info'), flux=c(), plot.range=TRUE, prob=.8, range.col=grey(0.5), range.lty=2, plot.mean=TRUE, mean.col="red", mean.lty=2, flux.lim=c(), flux.lab="flux", upper=.95, dark=set$dark, BCAD=set$BCAD, yr.lab=c(), rotate.axes=FALSE, rev.flux=FALSE, rev.yr=FALSE) {
+flux.age.ghost <- function(proxy=1, age.lim=c(), yr.lim=age.lim, age.res=200, yr.res=age.res, set=get('info'), flux=c(), plot.range=TRUE, prob=.8, range.col=grey(0.5), range.lty=2, plot.mean=TRUE, mean.col="red", mean.lty=2, flux.lim=c(), flux.lab="flux", upper=.95, dark=set$dark, BCAD=set$BCAD, age.lab=c(), yr.lab=age.lab, rotate.axes=FALSE, rev.flux=FALSE, rev.age=FALSE, rev.yr=rev.age) {
   if(length(flux) == 0) { # then read a .csv file, expecting data in columns with headers
     flux <- read.csv(paste(set$coredir, set$core, "/", set$core, "_flux.csv", sep=""))
     flux <- cbind(flux[,1], flux[,1+proxy])
       isNA <- is.na(flux[,2])
       flux <- flux[!isNA,]
   }
-  if(length(yr.lim) == 0) {
+  if(length(age.lim) == 0) {
     min.age <- min(set$ranges[,2])
     max.age <- max(set$ranges[,3])
-    yr.lim <- c(min.age, max.age)
+    age.lim <- c(min.age, max.age)
   } else {
-      min.age <- min(yr.lim)
-      max.age <- max(yr.lim)
+      min.age <- min(age.lim)
+      max.age <- max(age.lim)
     }
 	
-  age.seq <- seq(min(min.age, max.age), max(min.age, max.age), length=yr.res)
+  age.seq <- seq(min(min.age, max.age), max(min.age, max.age), length=age.res)
   fluxes <- array(NA, dim=c(nrow(set$output), length(age.seq)))
   for(i in 1:nrow(set$output)) {
     ages <- as.numeric(set$output[i,1:(ncol(set$output)-1)]) # 1st step to calculate ages for each set$d
@@ -408,13 +416,13 @@ flux.age.ghost <- function(proxy=1, yr.lim=c(), yr.res=200, set=get('info'), flu
       max.dens <- max(max.dens, density(tmp, from=0, to=max(flux.lim))$y)	
   }
 
-  if(length(yr.lim) == 0)
-    yr.lim <- range(age.seq)
-  if(length(yr.lab) == 0)
-    yr.lab <- ifelse(BCAD, "BC/AD", "cal BP")
+  if(length(age.lim) == 0)
+    age.lim <- range(age.seq)
+  if(length(age.lab) == 0)
+    age.lab <- ifelse(BCAD, "BC/AD", "cal BP")
   if(rotate.axes)
-    plot(0, type="n", ylim=yr.lim, ylab=yr.lab, xlim=flux.lim, xlab=flux.lab) else
-      plot(0, type="n", xlim=yr.lim, xlab=yr.lab, ylim=flux.lim, ylab=flux.lab)
+    plot(0, type="n", ylim=age.lim, ylab=age.lab, xlim=flux.lim, xlab=flux.lab) else
+      plot(0, type="n", xlim=age.lim, xlab=age.lab, ylim=flux.lim, ylab=flux.lab)
   min.rng <- c(); max.rng <- c(); mn.rng <- c()
   for(i in 2:length(age.seq)) {
     tmp <- fluxes[!is.na(fluxes[,i]),i] # all fluxes that fall at the required age.seq age
