@@ -3,16 +3,16 @@
 #################### user-invisible plot functions ####################
 
 # to plot greyscale/ghost graphs of the age-depth model
-.agedepth.ghost <- function(set=get('info'), d.min=set$d.min, d.max=set$d.max, BCAD=set$BCAD, rotate.axes=FALSE, d.res=400, yr.res=400, grey.res=100, dark=c(), colours=grey(seq(1, 0, length=100)), xaxt="s", yaxt="s", yr.lim) {
+.agedepth.ghost <- function(set=get('info'), d.min=set$d.min, d.max=set$d.max, BCAD=set$BCAD, rotate.axes=FALSE, d.res=400, age.res=400, grey.res=100, dark=c(), colours=grey(seq(1, 0, length=100)), xaxt="s", yaxt="s", age.lim) {
   dseq <- seq(d.min, d.max, length=d.res)
   Bacon.hist(dseq, set, BCAD=BCAD, calc.range=FALSE)
   hists <- get('hists') 
   
-  scales <- array(NA, dim=c(d.res, yr.res))
-  yrseq <- seq(min(yr.lim), max(yr.lim), length=yr.res)
+  scales <- array(NA, dim=c(d.res, age.res))
+  ageseq <- seq(min(age.lim), max(age.lim), length=age.res)
   for(i in 1:length(dseq)) {
-    yrs <- seq(hists[[i]]$th0, hists[[i]]$th1, length=hists[[i]]$n)
-    scales[i,] <- approx(yrs, hists[[i]]$counts, yrseq)$y
+    ages <- seq(hists[[i]]$th0, hists[[i]]$th1, length=hists[[i]]$n)
+    scales[i,] <- approx(ages, hists[[i]]$counts, ageseq)$y
   }
   minmax <- hists[[length(hists)]]$min
   maxmax <- hists[[length(hists)]]$max
@@ -22,8 +22,8 @@
   scales[scales > dark] <- dark 
   
   if(rotate.axes)
-    image(yrseq, dseq, t(scales), add=TRUE, col=colours, useRaster=FALSE) else
-      image(dseq, yrseq, scales, add=TRUE, col=colours, useRaster=FALSE)
+    image(ageseq, dseq, t(scales), add=TRUE, col=colours, useRaster=FALSE) else
+      image(dseq, ageseq, scales, add=TRUE, col=colours, useRaster=FALSE)
 }
 
 
@@ -36,12 +36,14 @@
 
 
 # plot the prior for the accumulation rate
-.PlotAccPrior <- function(s, mn, set=get('info'), main="", xlim=c(0, 3*max(mn)), xlab=paste("Acc. rate (yr/", noquote(set$unit), ")", sep=""), ylab="Density", add=FALSE, legend=TRUE, cex=.9) {
+.PlotAccPrior <- function(s, mn, set=get('info'), depth.unit=depth.unit, age.unit=age.unit, main="", xlim=c(0, 3*max(mn)), xlab=c(), ylab="Density", add=FALSE, legend=TRUE, cex=.9) {
   o <- order(s, decreasing=TRUE)
   priors <- unique(cbind(s[o],mn[o])[,1:2])
   x <- 0
+  if(length(xlab) == 0)
+	xlab <- paste0("Acc. rate (", noquote(age.unit), "/", noquote(depth.unit), ")")
   if(length(priors) == 2) {
-    curve(dgamma(x, s, s/mn), col=3, lwd=2, from=0, xlim=xlim, xlab=xlab, ylab=ylab, add=add)
+    curve(dgamma(x, s, s/mn), col=3, lwd=2, from=0, to=max(xlim), xlim=xlim, xlab=xlab, ylab=ylab, add=add)
     txt <- paste("acc.shape: ", priors[1], "\nacc.mean: ", priors[2])
   } else {
 	  priors <- priors[order(priors[,1]*priors[,2]),]
@@ -64,7 +66,7 @@
 
   if(length(priors)==2) {
     curve(dbeta(x, s*mn, s*(1-mn)), from=0, to=1, col=3, lwd=2, xlab=xlab, ylab=ylab, add=add)
-    txt <- paste("mem.strength: ", s, "\nmem.mean: ", mn, "\n", set$K, " ", round(thick,3), noquote(set$unit), " sections", sep="")
+    txt <- paste0("mem.strength: ", s, "\nmem.mean: ", mn, "\n", set$K, " ", round(thick,3)," ", noquote(set$depth.unit), " sections")
   } else {
 	  priors <- priors[order(priors[,1]*priors[,2]),]
       curve(dbeta(x, priors[1,1]*priors[1,2], priors[1,1]*(1-priors[1,2])), from=0, to=1, col=3, lwd=2, xlab=xlab, ylab=ylab, add=add)
@@ -85,7 +87,7 @@
 
 
 # plot the prior for the hiatus length
-.PlotHiatusPrior <- function(mx=set$hiatus.max, hiatus=set$hiatus.depths, set=get('info'), xlab="Hiatus size (yr)", ylab="Density", main="", xlim=c(0, 1.1*max(mx)), add=FALSE, legend=TRUE) {
+.PlotHiatusPrior <- function(mx=set$hiatus.max, hiatus=set$hiatus.depths, set=get('info'), xlab=paste0("Hiatus size (", set$age.unit, ")"), ylab="Density", main="", xlim=c(0, 1.1*max(mx)), add=FALSE, legend=TRUE) {
   if(add)
     lines(c(0, 0, mx, mx), c(0, 1/mx, 1/mx, 0), col=3, lwd=2) else
       plot(c(0, 0, mx, mx), c(0, 1/mx, 1/mx, 0), xlab=xlab, ylab=ylab, xlim=xlim, type="l", col=3, lwd=2)
@@ -98,7 +100,7 @@
 
 
 # plot the posterior (and prior) of the accumulation rate
-.PlotAccPost <- function(set=get('info'), s=set$acc.shape, mn=set$acc.mean, main="", xlab=paste("Acc. rate (yr/", set$unit, ")", sep=""), ylab="Frequency") {
+.PlotAccPost <- function(set=get('info'), s=set$acc.shape, mn=set$acc.mean, main="", depth.unit=set$depth.unit, age.unit=set$age.unit, ylab="Frequency") {
   hi <- 2:(set$K-1)
   if(!is.na(set$hiatus.depths)[1])
     for(i in set$hiatus.depths) 
@@ -114,9 +116,10 @@
     max.y <- max(post[,2]) else
       max.y <- max(maxprior, post[,2])
   lim.x <- range(0, post[,1], 2*mn)
-  plot(0, type="n", xlim=lim.x, xlab=xlab, ylim=c(0, 1.05*max.y), ylab="")
+  acc.lab <- paste0("Acc. rate (", age.unit, "/", depth.unit, ")")
+  plot(0, type="n", xlim=lim.x, xlab=acc.lab, ylim=c(0, 1.05*max.y), ylab="")
   polygon(post, col=grey(.8), border=grey(.4))
-  .PlotAccPrior(s, mn, add=TRUE, xlim=range(post[,1]), xlab="", ylab=ylab, main=main)
+  .PlotAccPrior(s, mn, add=TRUE, xlim=lim.x, xlab="", ylab=ylab, main=main)
 }
 
 
@@ -136,19 +139,17 @@
 
 
 # plot the posterior (and prior) of the hiatus
-.PlotHiatusPost <- function(set=get('info'), mx=set$hiatus.max, main="", xlim=c(), xlab=paste("Hiatus size (yr)", sep=""), ylab="Frequency", after=set$after) {
+.PlotHiatusPost <- function(set=get('info'), mx=set$hiatus.max, main="", xlim=c(), xlab=paste0("Hiatus size (", set$age.unit, ")"), ylab="Frequency", after=set$after) {
   gaps <- c()
   for(i in set$hiatus.depths) {
     below <- Bacon.Age.d(i+after, set)
     above <- Bacon.Age.d(i-after, set)
     gaps <- below - above 
-#    reversals <- which(below < above) 
-#    gaps <- c(gaps, below[-reversals] - above[-reversals])
   }
+  if(length(xlim) == 0)
+    xlim <- c(0, 1.1*(max(mx, gaps)))
   gaps <- density(gaps, from=0)
   max.y <- 1.1*max(1/mx, gaps$y)
-  if(length(xlim) == 0)
-    xlim <- c(0, 1.1*mx)
   plot(0, type="n", main="", xlab=xlab, xlim=xlim, ylab=ylab, ylim=c(0, max.y))
   polygon(cbind(c(min(gaps$x), gaps$x, max(gaps$x)), c(0,gaps$y,0)),
     col=grey(.8), border=grey(.4))
